import { __assign, __extends, __makeTemplateObject, __read, __spread } from "tslib";
import React from 'react';
import styled from '@emotion/styled';
import * as Sentry from '@sentry/react';
import isEqual from 'lodash/isEqual';
import partition from 'lodash/partition';
import CheckboxFancy from 'app/components/checkboxFancy/checkboxFancy';
import ExternalLink from 'app/components/links/externalLink';
import { t, tct } from 'app/locale';
import space from 'app/styles/space';
import { DynamicSamplingConditionOperator, DynamicSamplingInnerName, DynamicSamplingRuleType, } from 'app/types/dynamicSampling';
import Field from 'app/views/settings/components/forms/field';
import { DYNAMIC_SAMPLING_DOC_LINK } from '../utils';
import Form from './form';
import { Transaction } from './utils';
var TransactionRuleModal = /** @class */ (function (_super) {
    __extends(TransactionRuleModal, _super);
    function TransactionRuleModal() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.handleAddCondition = function () {
            _this.setState(function (state) { return ({
                conditions: __spread(state.conditions, [
                    {
                        category: state.tracing
                            ? DynamicSamplingInnerName.TRACE_RELEASE
                            : DynamicSamplingInnerName.EVENT_RELEASE,
                        match: '',
                    },
                ]),
            }); });
        };
        _this.handleSubmit = function () {
            var _a = _this.state, tracing = _a.tracing, sampleRate = _a.sampleRate, conditions = _a.conditions, transaction = _a.transaction;
            if (!sampleRate) {
                return;
            }
            var _b = _this.props, rule = _b.rule, errorRules = _b.errorRules, transactionRules = _b.transactionRules;
            var newRule = {
                type: tracing ? DynamicSamplingRuleType.TRACE : DynamicSamplingRuleType.TRANSACTION,
                condition: {
                    op: DynamicSamplingConditionOperator.AND,
                    inner: transaction === Transaction.ALL ? [] : conditions.map(_this.getNewCondition),
                },
                sampleRate: sampleRate / 100,
            };
            var newTransactionRules = rule
                ? transactionRules.map(function (transactionRule) {
                    return isEqual(transactionRule, rule) ? newRule : transactionRule;
                })
                : __spread(transactionRules, [newRule]);
            var _c = __read(partition(newTransactionRules, function (transactionRule) { return transactionRule.type === DynamicSamplingRuleType.TRACE; }), 2), transactionTraceRules = _c[0], individualTransactionRules = _c[1];
            var newRules = __spread(errorRules, transactionTraceRules, individualTransactionRules);
            var currentRuleIndex = newRules.findIndex(function (newR) { return newR === newRule; });
            _this.submitRules(newRules, currentRuleIndex);
        };
        return _this;
    }
    TransactionRuleModal.prototype.componentDidUpdate = function (prevProps, prevState) {
        if (prevState.tracing !== this.state.tracing && !!this.state.conditions.length) {
            this.updateConditions();
        }
        _super.prototype.componentDidUpdate.call(this, prevProps, prevState);
    };
    TransactionRuleModal.prototype.updateConditions = function () {
        var _this = this;
        this.setState(function (state) { return ({
            conditions: state.conditions.map(function (condition) { return (__assign(__assign({}, condition), { category: _this.getNewConditionCategory(condition.category) })); }),
        }); });
    };
    TransactionRuleModal.prototype.getDefaultState = function () {
        var rule = this.props.rule;
        if (rule) {
            return __assign(__assign({}, _super.prototype.getDefaultState.call(this)), { tracing: rule.type === DynamicSamplingRuleType.TRACE });
        }
        return __assign(__assign({}, _super.prototype.getDefaultState.call(this)), { tracing: true });
    };
    TransactionRuleModal.prototype.getModalTitle = function () {
        var rule = this.props.rule;
        if (rule) {
            return t('Edit a custom rule for transactions');
        }
        return t('Add a custom rule for transactions');
    };
    TransactionRuleModal.prototype.geTransactionFieldDescription = function () {
        return {
            label: t('Transaction'),
        };
    };
    TransactionRuleModal.prototype.getNewConditionCategory = function (category) {
        var tracing = this.state.tracing;
        if (!tracing) {
            switch (category) {
                case DynamicSamplingInnerName.TRACE_RELEASE:
                    return DynamicSamplingInnerName.EVENT_RELEASE;
                case DynamicSamplingInnerName.TRACE_USER:
                    return DynamicSamplingInnerName.EVENT_USER;
                case DynamicSamplingInnerName.TRACE_ENVIRONMENT:
                    return DynamicSamplingInnerName.EVENT_ENVIRONMENT;
                default: {
                    Sentry.withScope(function (scope) {
                        scope.setLevel(Sentry.Severity.Warning);
                        Sentry.captureException(new Error('Unknown dynamic sampling rule condition category'));
                    });
                    return category; //this shall not happen
                }
            }
        }
        switch (category) {
            case DynamicSamplingInnerName.EVENT_RELEASE:
                return DynamicSamplingInnerName.TRACE_RELEASE;
            case DynamicSamplingInnerName.EVENT_ENVIRONMENT:
                return DynamicSamplingInnerName.TRACE_ENVIRONMENT;
            case DynamicSamplingInnerName.EVENT_USER:
                return DynamicSamplingInnerName.TRACE_USER;
            default: {
                Sentry.withScope(function (scope) {
                    scope.setLevel(Sentry.Severity.Warning);
                    Sentry.captureException(new Error('Unknown dynamic sampling rule condition category'));
                });
                return category; //this shall not happen
            }
        }
    };
    TransactionRuleModal.prototype.getCategoryOptions = function () {
        var tracing = this.state.tracing;
        if (tracing) {
            return [
                [DynamicSamplingInnerName.TRACE_RELEASE, t('Releases')],
                [DynamicSamplingInnerName.TRACE_ENVIRONMENT, t('Environments')],
                [DynamicSamplingInnerName.TRACE_USER, t('Users')],
            ];
        }
        return [
            [DynamicSamplingInnerName.EVENT_RELEASE, t('Releases')],
            [DynamicSamplingInnerName.EVENT_ENVIRONMENT, t('Environments')],
            [DynamicSamplingInnerName.EVENT_USER, t('Users')],
        ];
    };
    TransactionRuleModal.prototype.getExtraFields = function () {
        var _this = this;
        var tracing = this.state.tracing;
        return (<Field label={t('Tracing')} 
        // help={t('this is a description')} // TODO(Priscila): Add correct descriptions
        inline={false} flexibleControlStateSize stacked showHelpInTooltip>
        <TracingWrapper>
          <StyledCheckboxFancy onClick={function () { return _this.handleChange('tracing', !tracing); }} isChecked={tracing}/>
          {tct('Include all related transactions by trace ID. This can span across multiple projects. All related errors will remain. [link:Learn more about tracing].', { link: <ExternalLink href={DYNAMIC_SAMPLING_DOC_LINK}/> })}
        </TracingWrapper>
      </Field>);
    };
    return TransactionRuleModal;
}(Form));
export default TransactionRuleModal;
var TracingWrapper = styled('div')(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  display: grid;\n  grid-template-columns: max-content 1fr;\n  grid-gap: ", ";\n"], ["\n  display: grid;\n  grid-template-columns: max-content 1fr;\n  grid-gap: ", ";\n"])), space(1));
var StyledCheckboxFancy = styled(CheckboxFancy)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  margin-top: ", ";\n"], ["\n  margin-top: ", ";\n"])), space(0.5));
var templateObject_1, templateObject_2;
//# sourceMappingURL=transactionRuleModal.jsx.map